Struct RestoreOnPending
pub struct RestoreOnPending(/* private fields */);Expand description
Value returned by the poll_proceed method.
Implementations
impl RestoreOnPending
impl RestoreOnPending
pub fn made_progress(&self)
pub fn made_progress(&self)
Signals that the task that obtained this RestoreOnPending was able to make
progress. This prevents the task budget from being restored to the value
it had prior to obtaining this instance when it is dropped.